@@ -59,8 +59,6 @@ class PhCalculation(CalcJob):
         spec.default_output_node = 'output_parameters'
 
         # Unrecoverable errors: required retrieved files could not be read, parsed or are otherwise incomplete
-        spec.exit_code(300, 'ERROR_NO_RETRIEVED_FOLDER',
-            message='The retrieved folder data node could not be accessed.')
         spec.exit_code(302, 'ERROR_OUTPUT_STDOUT_MISSING',
             message='The retrieved folder did not contain the required stdout output file.')
         spec.exit_code(305, 'ERROR_OUTPUT_FILES',
@@ -79,6 +77,7 @@ class PhCalculation(CalcJob):
             message='The calculation stopped prematurely because it ran out of walltime.')
         spec.exit_code(410, 'ERROR_CONVERGENCE_NOT_REACHED',
             message='The minimization cycle did not reach self-consistency.')
+        # yapf: enable
 
     def prepare_for_submission(self, folder):
         """Prepare the calculation job for submission by transforming input nodes into input files.
@@ -88,7 +87,7 @@ class PhCalculation(CalcJob):
         lists that are to be retrieved after job completion.
 
         :param folder: a sandbox folder to temporarily write files on disk.
-        :return: :py:`~aiida.common.datastructures.CalcInfo` instance.
+        :return: :py:class:`~aiida.common.datastructures.CalcInfo` instance.
         """
         # pylint: disable=too-many-statements,too-many-branches
         local_copy_list = []
@@ -104,10 +103,9 @@ class PhCalculation(CalcJob):
         parent_calcs = parent_folder.get_incoming(node_class=orm.CalcJobNode).all()
 
         if not parent_calcs:
-            raise exceptions.NotExistent('parent_folder<{}> has no parent calculation'.format(parent_folder.pk))
+            raise exceptions.NotExistent(f'parent_folder<{parent_folder.pk}> has no parent calculation')
         elif len(parent_calcs) > 1:
-            raise exceptions.UniquenessError(
-                'parent_folder<{}> has multiple parent calculations'.format(parent_folder.pk))
+            raise exceptions.UniquenessError(f'parent_folder<{parent_folder.pk}> has multiple parent calculations')
 
         parent_calc = parent_calcs[0].node
 
@@ -118,7 +116,9 @@ class PhCalculation(CalcJob):
         if not self.node.computer.uuid == parent_calc.computer.uuid:
             raise exceptions.InputValidationError(
                 'Calculation has to be launched on the same computer as that of the parent: {}'.format(
-                    parent_calc.computer.get_name()))
+                    parent_calc.computer.get_name()
+                )
+            )
 
         # put by default, default_parent_output_folder = ./out
         try:
@@ -126,8 +126,9 @@ class PhCalculation(CalcJob):
         except AttributeError:
             try:
                 default_parent_output_folder = parent_calc._get_output_folder()  # pylint: disable=protected-access
-            except AttributeError:
-                raise exceptions.InputValidationError('parent calculation does not have a default output subfolder')
+            except AttributeError as exception:
+                msg = 'parent calculation does not have a default output subfolder'
+                raise exceptions.InputValidationError(msg) from exception
         parent_calc_out_subfolder = settings.pop('PARENT_CALC_OUT_SUBFOLDER', default_parent_output_folder)
 
         # I put the first-level keys as uppercase (i.e., namelist and card names) and the second-level keys as lowercase
@@ -136,18 +137,15 @@ class PhCalculation(CalcJob):
 
         prepare_for_d3 = settings.pop('PREPARE_FOR_D3', False)
         if prepare_for_d3:
-            self._blocked_keywords += [
-                ('INPUTPH', 'fildrho'),
-                ('INPUTPH', 'drho_star%open'),
-                ('INPUTPH', 'drho_star%ext'),
-                ('INPUTPH', 'drho_star%dir')
-            ]
+            self._blocked_keywords += [('INPUTPH', 'fildrho'), ('INPUTPH', 'drho_star%open'),
+                                       ('INPUTPH', 'drho_star%ext'), ('INPUTPH', 'drho_star%dir')]
 
         for namelist, flag in self._blocked_keywords:
             if namelist in parameters:
                 if flag in parameters[namelist]:
                     raise exceptions.InputValidationError(
-                        "Cannot specify explicitly the '{}' flag in the '{}' namelist or card.".format(flag, namelist))
+                        f"Cannot specify explicitly the '{flag}' flag in the '{namelist}' namelist or card."
+                    )
 
         if 'INPUTPH' not in parameters:
             raise exceptions.InputValidationError('required namelist INPUTPH not specified')
@@ -173,7 +171,8 @@ class PhCalculation(CalcJob):
 
             if any([i != 0. for i in offset]):
                 raise NotImplementedError(
-                    'Computation of phonons on a mesh with non zero offset is not implemented, at the level of ph.x')
+                    'Computation of phonons on a mesh with non zero offset is not implemented, at the level of ph.x'
+                )
 
             parameters['INPUTPH']['ldisp'] = True
             parameters['INPUTPH']['nq1'] = mesh[0]
@@ -186,9 +185,10 @@ class PhCalculation(CalcJob):
             # this is the case where no mesh was set. Maybe it's a list
             try:
                 list_of_points = self.inputs.qpoints.get_kpoints(cartesian=True)
-            except AttributeError:
+            except AttributeError as exception:
                 # In this case, there are no info on the qpoints at all
-                raise exceptions.InputValidationError('Input `qpoints` contains neither a mesh nor a list of points')
+                msg = 'Input `qpoints` contains neither a mesh nor a list of points'
+                raise exceptions.InputValidationError(msg) from exception
 
             # change to 2pi/a coordinates
             lattice_parameter = numpy.linalg.norm(self.inputs.qpoints.cell[0])
@@ -198,7 +198,7 @@ class PhCalculation(CalcJob):
             if len(list_of_points) > 1:
                 parameters['INPUTPH']['qplot'] = True
                 parameters['INPUTPH']['ldisp'] = True
-                postpend_text = '{}\n'.format(len(list_of_points))
+                postpend_text = f'{len(list_of_points)}\n'
                 for points in list_of_points:
                     postpend_text += '{0:18.10f} {1:18.10f} {2:18.10f}  1\n'.format(*points)
 
@@ -217,7 +217,8 @@ class PhCalculation(CalcJob):
             if not isinstance(namelists_toprint, list):
                 raise exceptions.InputValidationError(
                     "The 'NAMELISTS' value, if specified in the settings input "
-                    'node, must be a list of strings')
+                    'node, must be a list of strings'
+                )
         except KeyError:  # list of namelists not specified in the settings; do automatic detection
             namelists_toprint = self._compulsory_namelists
 
@@ -227,7 +228,7 @@ class PhCalculation(CalcJob):
 
         with folder.open(self.metadata.options.input_filename, 'w') as infile:
             for namelist_name in namelists_toprint:
-                infile.write('&{0}\n'.format(namelist_name))
+                infile.write(f'&{namelist_name}\n')
                 # namelist content; set to {} if not present, so that we leave an empty namelist
                 namelist = parameters.pop(namelist_name, {})
                 for key, value in sorted(namelist.items()):
@@ -242,7 +243,8 @@ class PhCalculation(CalcJob):
             raise exceptions.InputValidationError(
                 'The following namelists are specified in parameters, but are '
                 'not valid namelists for the current type of calculation: '
-                '{}'.format(','.join(list(parameters.keys()))))
+                '{}'.format(','.join(list(parameters.keys())))
+            )
 
         # copy the parent scratch
         symlink = settings.pop('PARENT_FOLDER_SYMLINK', self._default_symlink_usage)  # a boolean
@@ -252,38 +254,34 @@ class PhCalculation(CalcJob):
 
             remote_symlink_list.append((
                 parent_folder.computer.uuid,
-                os.path.join(parent_folder.get_remote_path(), parent_calc_out_subfolder, '*'),
-                self._OUTPUT_SUBFOLDER
+                os.path.join(parent_folder.get_remote_path(), parent_calc_out_subfolder, '*'), self._OUTPUT_SUBFOLDER
             ))
 
             # I also create a symlink for the ./pseudo folder
             # Remove this when the recover option of QE will be fixed (bug when trying to find pseudo file)
             remote_symlink_list.append((
-                parent_folder.computer.uuid,
-                os.path.join(parent_folder.get_remote_path(), self._get_pseudo_folder()),
-                self._get_pseudo_folder()
+                parent_folder.computer.uuid, os.path.join(parent_folder.get_remote_path(),
+                                                          self._get_pseudo_folder()), self._get_pseudo_folder()
             ))
         else:
             # here I copy the whole folder ./out
             remote_copy_list.append((
-                parent_folder.computer.uuid,
-                os.path.join(parent_folder.get_remote_path(), parent_calc_out_subfolder),
-                self._OUTPUT_SUBFOLDER
+                parent_folder.computer.uuid, os.path.join(parent_folder.get_remote_path(),
+                                                          parent_calc_out_subfolder), self._OUTPUT_SUBFOLDER
             ))
             # I also copy the ./pseudo folder
             # Remove this when the recover option of QE will be fixed (bug when trying to find pseudo file)
             remote_copy_list.append((
-                parent_folder.computer.uuid,
-                os.path.join(parent_folder.get_remote_path(), self._get_pseudo_folder()),
-                self._get_pseudo_folder()
+                parent_folder.computer.uuid, os.path.join(parent_folder.get_remote_path(),
+                                                          self._get_pseudo_folder()), self._get_pseudo_folder()
             ))
 
         if restart_flag:  # in this case, copy in addition also the dynamical matrices
             if symlink:
                 remote_symlink_list.append((
                     parent_folder.computer.uuid,
-                    os.path.join(parent_folder.get_remote_path(), self._FOLDER_DYNAMICAL_MATRIX),
-                    self._FOLDER_DYNAMICAL_MATRIX
+                    os.path.join(parent_folder.get_remote_path(),
+                                 self._FOLDER_DYNAMICAL_MATRIX), self._FOLDER_DYNAMICAL_MATRIX
                 ))
 
             else:
@@ -291,19 +289,17 @@ class PhCalculation(CalcJob):
                 # no need to copy the _ph0, since I copied already the whole ./out folder
                 remote_copy_list.append((
                     parent_folder.computer.uuid,
-                    os.path.join(parent_folder.get_remote_path(), self._FOLDER_DYNAMICAL_MATRIX),
-                    '.'
+                    os.path.join(parent_folder.get_remote_path(), self._FOLDER_DYNAMICAL_MATRIX), '.'
                 ))
 
         # Create an `.EXIT` file if `only_initialization` flag in `settings` is set to `True`
         if settings.pop('ONLY_INITIALIZATION', False):
-            with folder.open('{}.EXIT'.format(self._PREFIX), 'w') as handle:
+            with folder.open(f'{self._PREFIX}.EXIT', 'w') as handle:
                 handle.write('\n')
 
                 remote_copy_list.append((
                     parent_folder.computer.uuid,
-                    os.path.join(parent_folder.get_remote_path(), self._FOLDER_DYNAMICAL_MATRIX),
-                    '.'
+                    os.path.join(parent_folder.get_remote_path(), self._FOLDER_DYNAMICAL_MATRIX), '.'
                 ))
 
         codeinfo = datastructures.CodeInfo()
@@ -319,7 +315,7 @@ class PhCalculation(CalcJob):
         calcinfo.remote_symlink_list = remote_symlink_list
 
         # Retrieve by default the output file and the xml file
-        filepath_xml_tensor = os.path.join(self._OUTPUT_SUBFOLDER, '_ph0', '{}.phsave'.format(self._PREFIX))
+        filepath_xml_tensor = os.path.join(self._OUTPUT_SUBFOLDER, '_ph0', f'{self._PREFIX}.phsave')
         calcinfo.retrieve_list = []
         calcinfo.retrieve_list.append(self.metadata.options.output_filename)
         calcinfo.retrieve_list.append(self._FOLDER_DYNAMICAL_MATRIX)
@@ -328,11 +324,10 @@ class PhCalculation(CalcJob):
 
         if settings:
             unknown_keys = ', '.join(list(settings.keys()))
-            raise exceptions.InputValidationError('`settings` contained unexpected keys: {}'.format(unknown_keys))
+            raise exceptions.InputValidationError(f'`settings` contained unexpected keys: {unknown_keys}')
 
         return calcinfo
 
-
     @staticmethod
     def _get_pseudo_folder():
         """Get the calculation-specific pseudo folder (relative path).
