@@ -1,25 +1,26 @@
 # -*- coding: utf-8 -*-
 """Command line scripts to launch a `MatdynCalculation` for testing and demonstration purposes."""
-from aiida.cmdline.params import options, types
+from aiida.cmdline.params import options as options_core
+from aiida.cmdline.params import types
 from aiida.cmdline.utils import decorators
 
 from ..utils import launch
-from ..utils import options as options_qe
+from ..utils import options
 from . import cmd_launch
 
 
 @cmd_launch.command('matdyn')
-@options.CODE(required=True, type=types.CodeParamType(entry_point='quantumespresso.matdyn'))
-@options.DATUM(
+@options_core.CODE(required=True, type=types.CodeParamType(entry_point='quantumespresso.matdyn'))
+@options_core.DATUM(
     required=True,
     type=types.DataParamType(sub_classes=('aiida.data:quantumespresso.force_constants',)),
     help='A ForceConstantsData node produced by a `Q2rCalculation`'
 )
-@options_qe.KPOINTS_MESH(default=[1, 1, 1])
-@options_qe.MAX_NUM_MACHINES()
-@options_qe.MAX_WALLCLOCK_SECONDS()
-@options_qe.WITH_MPI()
-@options_qe.DAEMON()
+@options.KPOINTS_MESH(default=[1, 1, 1])
+@options.MAX_NUM_MACHINES()
+@options.MAX_WALLCLOCK_SECONDS()
+@options.WITH_MPI()
+@options.DAEMON()
 @decorators.with_dbenv()
 def launch_calculation(code, datum, kpoints_mesh, max_num_machines, max_wallclock_seconds, with_mpi, daemon):
     """Run a MatdynCalculation."""
