@@ -2,34 +2,34 @@
 """Command line scripts to launch a `PwBandsWorkChain` for testing and demonstration purposes."""
 import click
 
-from aiida.cmdline.params import options as options_cli
+from aiida.cmdline.params import options as options_core
 from aiida.cmdline.params import types
 from aiida.cmdline.utils import decorators
 
 from ...utils import launch
-from ...utils import options as options_qe
+from ...utils import options
 from ...utils import validate
 from .. import cmd_launch
 
 
 @cmd_launch.command('pw-bands')
-@options_cli.CODE(required=True, type=types.CodeParamType(entry_point='quantumespresso.pw'))
-@options_qe.STRUCTURE(required=True)
-@options_qe.PSEUDO_FAMILY(required=True)
-@options_qe.KPOINTS_DISTANCE()
-@options_qe.ECUTWFC()
-@options_qe.ECUTRHO()
-@options_qe.HUBBARD_U()
-@options_qe.HUBBARD_V()
-@options_qe.HUBBARD_FILE()
-@options_qe.STARTING_MAGNETIZATION()
-@options_qe.SMEARING()
-@options_qe.AUTOMATIC_PARALLELIZATION()
-@options_qe.CLEAN_WORKDIR()
-@options_qe.MAX_NUM_MACHINES()
-@options_qe.MAX_WALLCLOCK_SECONDS()
-@options_qe.WITH_MPI()
-@options_qe.DAEMON()
+@options_core.CODE(required=True, type=types.CodeParamType(entry_point='quantumespresso.pw'))
+@options.STRUCTURE(required=True)
+@options.PSEUDO_FAMILY()
+@options.KPOINTS_DISTANCE()
+@options.ECUTWFC()
+@options.ECUTRHO()
+@options.HUBBARD_U()
+@options.HUBBARD_V()
+@options.HUBBARD_FILE()
+@options.STARTING_MAGNETIZATION()
+@options.SMEARING()
+@options.AUTOMATIC_PARALLELIZATION()
+@options.CLEAN_WORKDIR()
+@options.MAX_NUM_MACHINES()
+@options.MAX_WALLCLOCK_SECONDS()
+@options.WITH_MPI()
+@options.DAEMON()
 @decorators.with_dbenv()
 def launch_workflow(
     code, structure, pseudo_family, kpoints_distance, ecutwfc, ecutrho, hubbard_u, hubbard_v, hubbard_file_pk,
@@ -38,16 +38,23 @@ def launch_workflow(
 ):
     """Run a `PwBandsWorkChain`."""
     # pylint: disable=too-many-statements
-    from aiida.orm import Bool, Float, Str, Dict
+    from aiida.orm import Bool, Float, Dict
     from aiida.plugins import WorkflowFactory
+    from qe_tools import CONSTANTS
+
     from aiida_quantumespresso.utils.resources import get_default_options, get_automatic_parallelization_options
 
     builder = WorkflowFactory('quantumespresso.pw.bands').get_builder()
 
+    cutoff_wfc, cutoff_rho = pseudo_family.get_recommended_cutoffs(structure=structure)
+
     parameters = {
+        'CONTROL': {
+            'calculation': 'relax',
+        },
         'SYSTEM': {
-            'ecutwfc': ecutwfc,
-            'ecutrho': ecutrho,
+            'ecutwfc': ecutwfc or cutoff_wfc / CONSTANTS.ry_to_ev,
+            'ecutrho': ecutrho or cutoff_rho / CONSTANTS.ry_to_ev,
         },
     }
 
@@ -68,22 +75,22 @@ def launch_workflow(
     except ValueError as exception:
         raise click.BadParameter(str(exception))
 
-    pseudo_family = Str(pseudo_family)
+    pseudos = pseudo_family.get_pseudos(structure=structure)
     parameters = Dict(dict=parameters)
 
     builder.structure = structure
     builder.relax.base.pw.code = code
     builder.relax.base.pw.parameters = parameters
-    builder.relax.base.pseudo_family = pseudo_family
+    builder.relax.base.pw.pseudos = pseudos
     builder.relax.base.kpoints_distance = Float(kpoints_distance)
     builder.relax.meta_convergence = Bool(False)
     builder.scf.pw.code = code
     builder.scf.pw.parameters = parameters
-    builder.scf.pseudo_family = pseudo_family
+    builder.scf.pw.pseudos = pseudos
     builder.scf.kpoints_distance = Float(kpoints_distance)
     builder.bands.pw.code = code
     builder.bands.pw.parameters = parameters
-    builder.bands.pseudo_family = pseudo_family
+    builder.bands.pw.pseudos = pseudos
 
     if hubbard_file:
         builder.relax.base.pw.hubbard_file = hubbard_file
@@ -96,10 +103,10 @@ def launch_workflow(
         builder.scf.automatic_parallelization = auto_para
         builder.bands.automatic_parallelization = auto_para
     else:
-        options = get_default_options(max_num_machines, max_wallclock_seconds, with_mpi)
-        builder.relax.base.pw.metadata.options = options
-        builder.scf.pw.metadata.options = options
-        builder.bands.pw.metadata.options = options
+        metadata_options = get_default_options(max_num_machines, max_wallclock_seconds, with_mpi)
+        builder.relax.base.pw.metadata.options = metadata_options
+        builder.scf.pw.metadata.options = metadata_options
+        builder.bands.pw.metadata.options = metadata_options
 
     if clean_workdir:
         builder.clean_workdir = Bool(True)
