@@ -4,7 +4,7 @@ import fnmatch
 
 import numpy as np
 
-from aiida.common import NotExistent, LinkType
+from aiida.common import LinkType
 from aiida.orm import Dict, ProjectionData, BandsData, XyData, CalcJobNode
 from aiida.plugins import OrbitalFactory
 
@@ -20,11 +20,47 @@ def find_orbitals_from_statelines(out_info_dict):
     :param out_info_dict: contains various technical internals useful in parsing
     :return: orbitals, a list of orbitals suitable for setting ProjectionData
     """
+
+    # Format of statelines
+    # From PP/src/projwfc.f90: (since Oct. 8 2019)
+    #
+    # 1000 FORMAT (5x,"state #",i4,": atom ",i3," (",a3,"), wfc ",i2," (l=",i1)
+    # IF (lspinorb) THEN
+    # 1001 FORMAT (" j=",f3.1," m_j=",f4.1,")")
+    # ELSE IF (noncolin) THEN
+    # 1002 FORMAT (" m=",i2," s_z=",f4.1,")")
+    # ELSE
+    # 1003 FORMAT (" m=",i2,")")
+    # ENDIF
+    #
+    # Before:
+    # IF (lspinorb) THEN
+    # ...
+    # 1000    FORMAT (5x,"state #",i4,": atom ",i3," (",a3,"), wfc ",i2, &
+    #               " (j=",f3.1," l=",i1," m_j=",f4.1,")")
+    # ELSE
+    # ...
+    # 1500    FORMAT (5x,"state #",i4,": atom ",i3," (",a3,"), wfc ",i2, &
+    #               " (l=",i1," m=",i2," s_z=",f4.1,")")
+    # ENDIF
+
     out_file = out_info_dict['out_file']
-    atomnum_re = re.compile(r'atom (.*?)\(')
-    element_re = re.compile(r'\((.*?)\)')
-    lnum_re = re.compile(r'l=(.*?)m=')
-    mnum_re = re.compile(r'm=(.*?)\)')
+    atomnum_re = re.compile(r'atom\s*([0-9]+?)[^0-9]')
+    element_re = re.compile(r'atom\s*[0-9]+\s*\(\s*([A-Za-z0-9-_]+?)\s*\)')
+    if out_info_dict['spinorbit']:
+        # spinorbit
+        lnum_re = re.compile(r'l=\s*([0-9]+?)[^0-9]')
+        jnum_re = re.compile(r'j=\s*([0-9.]+?)[^0-9.]')
+        mjnum_re = re.compile(r'm_j=\s*([-0-9.]+?)[^-0-9.]')
+    elif not out_info_dict['collinear']:
+        # non-collinear
+        lnum_re = re.compile(r'l=\s*([0-9]+?)[^0-9]')
+        mnum_re = re.compile(r'm=\s*([-0-9]+?)[^-0-9]')
+        sznum_re = re.compile(r's_z=\s*([-0-9.]*?)[^-0-9.]')
+    else:
+        # collinear / no spin
+        lnum_re = re.compile(r'l=\s*([0-9]+?)[^0-9]')
+        mnum_re = re.compile(r'm=\s*([-0-9]+?)[^-0-9]')
     wfc_lines = out_info_dict['wfc_lines']
     state_lines = [out_file[wfc_line] for wfc_line in wfc_lines]
     state_dicts = []
@@ -35,8 +71,14 @@ def find_orbitals_from_statelines(out_info_dict):
             state_dict['atomnum'] -= 1  # to keep with orbital indexing
             state_dict['kind_name'] = element_re.findall(state_line)[0].strip()
             state_dict['angular_momentum'] = int(lnum_re.findall(state_line)[0])
-            state_dict['magnetic_number'] = int(mnum_re.findall(state_line)[0])
-            state_dict['magnetic_number'] -= 1  # to keep with orbital indexing
+            if out_info_dict['spinorbit']:
+                state_dict['total_angular_momentum'] = float(jnum_re.findall(state_line)[0])
+                state_dict['magnetic_number'] = float(mjnum_re.findall(state_line)[0])
+            else:
+                if not out_info_dict['collinear']:
+                    state_dict['spin'] = float(sznum_re.findall(state_line)[0])
+                state_dict['magnetic_number'] = int(mnum_re.findall(state_line)[0])
+                state_dict['magnetic_number'] -= 1  # to keep with orbital indexing
         except ValueError:
             raise QEOutputParsingError('State lines are not formatted in a standard way.')
         state_dicts.append(state_dict)
@@ -61,9 +103,14 @@ def find_orbitals_from_statelines(out_info_dict):
 
     # here we set the resulting state_dicts to a new set of orbitals
     orbitals = []
-    RealhydrogenOrbital = OrbitalFactory('realhydrogen')
+    if out_info_dict['spinorbit']:
+        OrbitalCls = OrbitalFactory('spinorbithydrogen')
+    elif not out_info_dict['collinear']:
+        OrbitalCls = OrbitalFactory('noncollinearhydrogen')
+    else:
+        OrbitalCls = OrbitalFactory('realhydrogen')
     for state_dict in state_dicts:
-        orbitals.append(RealhydrogenOrbital(**state_dict))
+        orbitals.append(OrbitalCls(**state_dict))
 
     return orbitals
 
@@ -75,10 +122,9 @@ def spin_dependent_subparser(out_info_dict):
     :param out_info_dict: contains various technical internals useful in parsing
     :return: ProjectionData, BandsData parsed from out_file
     """
-
     out_file = out_info_dict['out_file']
     spin_down = out_info_dict['spin_down']
-    od = out_info_dict  #using a shorter name for convenience
+    od = out_info_dict  # using a shorter name for convenience
     #   regular expressions needed for later parsing
     WaveFraction1_re = re.compile(r'\=(.*?)\*')  # state composition 1
     WaveFractionremain_re = re.compile(r'\+(.*?)\*')  # state comp 2
@@ -96,12 +142,12 @@ def spin_dependent_subparser(out_info_dict):
             for j in range(i * od['num_bands'], (i + 1) * od['num_bands'], 1):
                 out_ind = od['e_lines'][j]
                 try:
-                    # post ~6.3 output format "e ="
+                    # post ~6.3 <6.5 output format "e ="
                     val = out_file[out_ind].split()[2]
                     float(val)
                 except ValueError:
-                    # pre ~6.3 output format? "==== e("
-                    val = out_file[out_ind].split()[4]
+                    # pre ~6.3 and 6.5+ output format "==== e("
+                    val = out_file[out_ind].split(' = ')[1].split()[0]
                 bands[i % od['k_states']][j % od['num_bands']] = val
                 #subloop grabs pdos
                 wave_fraction = []
@@ -190,6 +236,8 @@ def spin_dependent_pdos_subparser(out_info_dict):
     :return: (pdos_name, pdos_array) tuples for all the specific pdos
     """
     spin = out_info_dict['spin']
+    collinear = out_info_dict.get('collinear', True)
+    spinorbit = out_info_dict.get('spinorbit', False)
     spin_down = out_info_dict['spin_down']
     pdos_atm_array_dict = out_info_dict['pdos_atm_array_dict']
     if spin:
@@ -210,8 +258,16 @@ def spin_dependent_pdos_subparser(out_info_dict):
     # both are produced in the same order (thus the sorted file_names)
     for name in pdos_file_names:
         this_array = pdos_atm_array_dict[name]
-        for i in range(fa, np.shape(this_array)[1], mf):
-            out_arrays.append(this_array[:, i])
+        if not collinear and not spinorbit:
+            # In the non-collinear, non-spinorbit case, the "up"-spin orbitals
+            # come first, followed by all "down" orbitals
+            for i in range(3, np.shape(this_array)[1], 2):
+                out_arrays.append(this_array[:, i])
+            for i in range(4, np.shape(this_array)[1], 2):
+                out_arrays.append(this_array[:, i])
+        else:
+            for i in range(fa, np.shape(this_array)[1], mf):
+                out_arrays.append(this_array[:, i])
 
     return out_arrays
 
@@ -229,15 +285,12 @@ class ProjwfcParser(Parser):
         Retrieves projwfc output, and some basic information from the out_file, such as warnings and wall_time
         """
         # Check that the retrieved folder is there
-        try:
-            out_folder = self.retrieved
-        except NotExistent:
-            return self.exit(self.exit_codes.ERROR_NO_RETRIEVED_FOLDER)
+        retrieved = self.retrieved
 
         # Read standard out
         try:
             filename_stdout = self.node.get_option('output_filename')  # or get_attribute(), but this is clearer
-            with out_folder.open(filename_stdout, 'r') as fil:
+            with retrieved.open(filename_stdout, 'r') as fil:
                 out_file = fil.readlines()
         except OSError:
             return self.exit(self.exit_codes.ERROR_OUTPUT_STDOUT_READ)
@@ -257,12 +310,12 @@ class ProjwfcParser(Parser):
         self.out('output_parameters', Dict(dict=parsed_data))
 
         # check and read pdos_tot file
-        out_filenames = out_folder.list_object_names()
+        out_filenames = retrieved.list_object_names()
         try:
             pdostot_filename = fnmatch.filter(out_filenames, '*pdos_tot*')[0]
-            with out_folder.open(pdostot_filename, 'r') as pdostot_file:
+            with retrieved.open(pdostot_filename, 'r') as pdostot_file:
                 # Columns: Energy(eV), Ldos, Pdos
-                pdostot_array = np.genfromtxt(pdostot_file)
+                pdostot_array = np.atleast_2d(np.genfromtxt(pdostot_file))
                 energy = pdostot_array[:, 0]
                 dos = pdostot_array[:, 1]
         except (OSError, KeyError):
@@ -272,8 +325,8 @@ class ProjwfcParser(Parser):
         pdos_atm_filenames = fnmatch.filter(out_filenames, '*pdos_atm*')
         pdos_atm_array_dict = {}
         for name in pdos_atm_filenames:
-            with out_folder.open(name, 'r') as pdosatm_file:
-                pdos_atm_array_dict[name] = np.genfromtxt(pdosatm_file)
+            with retrieved.open(name, 'r') as pdosatm_file:
+                pdos_atm_array_dict[name] = np.atleast_2d(np.genfromtxt(pdosatm_file))
 
         # finding the bands and projections
         # we create a dictionary the progressively accumulates more info
@@ -284,7 +337,7 @@ class ProjwfcParser(Parser):
         try:
             new_nodes_list = self._parse_bands_and_projections(out_info_dict)
         except QEOutputParsingError as err:
-            self.logger.error('Error parsing bands and projections: {}'.format(err))
+            self.logger.error(f'Error parsing bands and projections: {err}')
             return self.exit(self.exit_codes.ERROR_PARSING_PROJECTIONS)
         for linkname, node in new_nodes_list:
             self.out(linkname, node)
@@ -337,7 +390,7 @@ class ProjwfcParser(Parser):
                                                             link_type=LinkType.CREATE).one().node
             )
         except ValueError as e:
-            raise QEOutputParsingError('Could not get parent calculation of input folder: {}'.format(e))
+            raise QEOutputParsingError(f'Could not get parent calculation of input folder: {e}')
         out_info_dict['parent_calc'] = parent_calc
         try:
             parent_param = parent_calc.get_outgoing(link_label_filter='output_parameters').one().node
@@ -353,8 +406,17 @@ class ProjwfcParser(Parser):
                 spin = True
             else:
                 spin = False
+            out_info_dict['spinorbit'] = parent_param.get_dict().get('spin_orbit_calculation', False)
+            out_info_dict['collinear'] = not parent_param.get_dict().get('non_colinear_calculation', False)
+            if not out_info_dict['collinear']:
+                # Sanity check
+                if nspin != 4:
+                    raise QEOutputParsingError('The calculation is non-collinear, but nspin is not set to 4!')
+                spin = False
         except KeyError:
             spin = False
+            out_info_dict['spinorbit'] = False
+            out_info_dict['collinear'] = True
         out_info_dict['spin'] = spin
 
         # changes k-numbers to match spin
