@@ -8,6 +8,8 @@ from aiida.engine import WorkChain, ToContext, if_
 from aiida_quantumespresso.calculations.functions.seekpath_structure_analysis import seekpath_structure_analysis
 from aiida_quantumespresso.utils.mapping import prepare_process_inputs
 
+from ..protocols.utils import ProtocolMixin
+
 PwBaseWorkChain = WorkflowFactory('quantumespresso.pw.base')
 PwRelaxWorkChain = WorkflowFactory('quantumespresso.pw.relax')
 
@@ -24,7 +26,7 @@ def validate_inputs(inputs, ctx=None):  # pylint: disable=unused-argument
         return PwBandsWorkChain.exit_codes.ERROR_INVALID_INPUT_KPOINTS.message
 
 
-class PwBandsWorkChain(WorkChain):
+class PwBandsWorkChain(ProtocolMixin, WorkChain):
     """Workchain to compute a band structure for a given structure using Quantum ESPRESSO pw.x.
 
     The logic for the computation of various parameters for the BANDS step is as follows:
@@ -97,8 +99,10 @@ class PwBandsWorkChain(WorkChain):
         spec.exit_code(403, 'ERROR_SUB_PROCESS_FAILED_BANDS',
             message='The bands PwBasexWorkChain sub process failed')
         spec.output('primitive_structure', valid_type=orm.StructureData,
+            required=False,
             help='The normalized and primitivized structure for which the bands are computed.')
         spec.output('seekpath_parameters', valid_type=orm.Dict,
+            required=False,
             help='The parameters used in the SeeKpath call to normalize the input or relaxed structure.')
         spec.output('scf_parameters', valid_type=orm.Dict,
             help='The output parameters of the SCF `PwBaseWorkChain`.')
@@ -106,6 +110,47 @@ class PwBandsWorkChain(WorkChain):
             help='The output parameters of the BANDS `PwBaseWorkChain`.')
         spec.output('band_structure', valid_type=orm.BandsData,
             help='The computed band structure.')
+        # yapf: enable
+
+    @classmethod
+    def get_builder_from_protocol(cls, code, structure, protocol=None, overrides=None, **kwargs):
+        """Return a builder prepopulated with inputs selected according to the chosen protocol.
+
+        :param code: the ``Code`` instance configured for the ``quantumespresso.pw`` plugin.
+        :param structure: the ``StructureData`` instance to use.
+        :param protocol: protocol to use, if not specified, the default will be used.
+        :param overrides: optional dictionary of inputs to override the defaults of the protocol.
+        :param kwargs: additional keyword arguments that will be passed to the ``get_builder_from_protocol`` of all the
+            sub processes that are called by this workchain.
+        :return: a process builder instance with all inputs defined ready for launch.
+        """
+        args = (code, structure, protocol)
+        inputs = cls.get_protocol_inputs(protocol, overrides)
+        builder = cls.get_builder()
+
+        relax = PwRelaxWorkChain.get_builder_from_protocol(*args, overrides=inputs.get('relax', None), **kwargs)
+        scf = PwBaseWorkChain.get_builder_from_protocol(*args, overrides=inputs.get('scf', None), **kwargs)
+        bands = PwBaseWorkChain.get_builder_from_protocol(*args, overrides=inputs.get('bands', None), **kwargs)
+
+        relax.pop('structure', None)
+        relax.pop('clean_workdir', None)
+        relax.pop('base_final_scf', None)
+        scf['pw'].pop('structure', None)
+        scf.pop('clean_workdir', None)
+        bands['pw'].pop('structure', None)
+        bands.pop('clean_workdir', None)
+        bands.pop('kpoints_distance', None)
+        bands.pop('kpoints_force_parity', None)
+
+        builder.structure = structure
+        builder.relax = relax
+        builder.scf = scf
+        builder.bands = bands
+        builder.clean_workdir = orm.Bool(inputs['clean_workdir'])
+        builder.nbands_factor = orm.Float(inputs['nbands_factor'])
+        builder.bands_kpoints_distance = orm.Float(inputs['bands_kpoints_distance'])
+
+        return builder
 
     def setup(self):
         """Define the current structure in the context to be the input structure."""
@@ -129,7 +174,7 @@ class PwBandsWorkChain(WorkChain):
 
         running = self.submit(PwRelaxWorkChain, **inputs)
 
-        self.report('launching PwRelaxWorkChain<{}>'.format(running.pk))
+        self.report(f'launching PwRelaxWorkChain<{running.pk}>')
 
         return ToContext(workchain_relax=running)
 
@@ -138,7 +183,7 @@ class PwBandsWorkChain(WorkChain):
         workchain = self.ctx.workchain_relax
 
         if not workchain.is_finished_ok:
-            self.report('PwRelaxWorkChain failed with exit status {}'.format(workchain.exit_status))
+            self.report(f'PwRelaxWorkChain failed with exit status {workchain.exit_status}')
             return self.exit_codes.ERROR_SUB_PROCESS_FAILED_RELAX
 
         self.ctx.current_structure = workchain.outputs.output_structure
@@ -151,7 +196,9 @@ class PwBandsWorkChain(WorkChain):
         """
         inputs = {
             'reference_distance': self.inputs.get('bands_kpoints_distance', None),
-            'metadata': {'call_link_label': 'seekpath'}
+            'metadata': {
+                'call_link_label': 'seekpath'
+            }
         }
         result = seekpath_structure_analysis(self.ctx.current_structure, **inputs)
         self.ctx.current_structure = result['primitive_structure']
@@ -177,7 +224,7 @@ class PwBandsWorkChain(WorkChain):
         inputs = prepare_process_inputs(PwBaseWorkChain, inputs)
         running = self.submit(PwBaseWorkChain, **inputs)
 
-        self.report('launching PwBaseWorkChain<{}> in {} mode'.format(running.pk, 'scf'))
+        self.report(f'launching PwBaseWorkChain<{running.pk}> in scf mode')
 
         return ToContext(workchain_scf=running)
 
@@ -186,7 +233,7 @@ class PwBandsWorkChain(WorkChain):
         workchain = self.ctx.workchain_scf
 
         if not workchain.is_finished_ok:
-            self.report('scf PwBaseWorkChain failed with exit status {}'.format(workchain.exit_status))
+            self.report(f'scf PwBaseWorkChain failed with exit status {workchain.exit_status}')
             return self.exit_codes.ERROR_SUB_PROCESS_FAILED_SCF
 
         self.ctx.current_folder = workchain.outputs.remote_folder
@@ -215,10 +262,16 @@ class PwBandsWorkChain(WorkChain):
         if 'nbands_factor' in self.inputs:
             factor = self.inputs.nbands_factor.value
             parameters = self.ctx.workchain_scf.outputs.output_parameters.get_dict()
-            nspin = int(parameters['number_of_spin_components'])
+            if int(parameters['number_of_spin_components']) > 1:
+                nspin_factor = 2
+            else:
+                nspin_factor = 1
             nbands = int(parameters['number_of_bands'])
             nelectron = int(parameters['number_of_electrons'])
-            nbnd = max(int(0.5 * nelectron * nspin * factor), int(0.5 * nelectron * nspin) + 4 * nspin, nbands)
+            nbnd = max(
+                int(0.5 * nelectron * nspin_factor * factor),
+                int(0.5 * nelectron * nspin_factor) + 4 * nspin_factor, nbands
+            )
             inputs.pw.parameters['SYSTEM']['nbnd'] = nbnd
 
         # Otherwise set the current number of bands, unless explicitly set in the inputs
@@ -228,7 +281,7 @@ class PwBandsWorkChain(WorkChain):
         inputs = prepare_process_inputs(PwBaseWorkChain, inputs)
         running = self.submit(PwBaseWorkChain, **inputs)
 
-        self.report('launching PwBaseWorkChain<{}> in {} mode'.format(running.pk, 'bands'))
+        self.report(f'launching PwBaseWorkChain<{running.pk}> in bands mode')
 
         return ToContext(workchain_bands=running)
 
@@ -237,7 +290,7 @@ class PwBandsWorkChain(WorkChain):
         workchain = self.ctx.workchain_bands
 
         if not workchain.is_finished_ok:
-            self.report('bands PwBaseWorkChain failed with exit status {}'.format(workchain.exit_status))
+            self.report(f'bands PwBaseWorkChain failed with exit status {workchain.exit_status}')
             return self.exit_codes.ERROR_SUB_PROCESS_FAILED_BANDS
 
     def results(self):
@@ -266,4 +319,4 @@ class PwBandsWorkChain(WorkChain):
                     pass
 
         if cleaned_calcs:
-            self.report('cleaned remote folders of calculations: {}'.format(' '.join(map(str, cleaned_calcs))))
+            self.report(f"cleaned remote folders of calculations: {' '.join(map(str, cleaned_calcs))}")
